@@ -25,7 +25,7 @@
 
 extern "C"
 {
-  KDE_EXPORT KDecorationFactory *create_factory()
+  TDE_EXPORT KDecorationFactory *create_factory()
   {
     return new SuSEMachBunt::BuntFactory();
   }
